"use strict";

require("core-js/modules/es6.regexp.to-string");

var _chai = require("chai");

var _nock = _interopRequireDefault(require("nock"));

var _dist = _interopRequireDefault(require("../dist"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('actions', function () {
  it('cancel()', function (done) {
    var isSuccess = false;
    var isError = false;
    (0, _nock.default)(_utils.ROOT).get('/delay').delayConnection(200).reply(200, {
      status: 0
    });
    var req = (0, _dist.default)({
      url: "".concat(_utils.ROOT, "/delay"),
      success: function success() {
        isSuccess = true;
      },
      error: function error() {
        isError = true;
      }
    });
    var startTime = new Date().getTime();

    function fetchDone() {
      (0, _chai.expect)(isSuccess).to.be.false;
      (0, _chai.expect)(isError).to.be.false;
      (0, _chai.expect)(new Date().getTime() - startTime).to.be.above(300);
      done();
    }

    req.send().then(fetchDone).catch(fetchDone);
    setTimeout(function () {
      req.cancel();
    }, 100);
    setTimeout(fetchDone, 300);
  });
  it('error()', function (done) {
    var isSuccess = false;
    var isError = false;
    (0, _nock.default)(_utils.ROOT).get('/delay').delayConnection(200).reply(200, {
      status: 0
    });
    var req = (0, _dist.default)({
      url: "".concat(_utils.ROOT, "/delay"),
      success: function success() {
        isSuccess = true;
      },
      error: function error(res) {
        isError = true;
        (0, _chai.expect)(res.status).to.equal(6);
        (0, _chai.expect)(res.customError).to.be.an('error');
        (0, _chai.expect)(res.customError.toString()).to.be.include('test');
      }
    });
    var startTime = new Date().getTime();

    function fetchDone() {
      (0, _chai.expect)(isSuccess).to.be.false;
      (0, _chai.expect)(isError).to.be.true;
      (0, _chai.expect)(new Date().getTime() - startTime).to.be.above(300);
      done();
    }

    req.send().then(fetchDone).catch(fetchDone);
    setTimeout(function () {
      req.error(new Error('test'));
    }, 100);
    setTimeout(fetchDone, 300);
  });
});