"use strict";

require("core-js/modules/es6.object.assign");

var _chai = require("chai");

var _nock = _interopRequireDefault(require("nock"));

var _dist = _interopRequireDefault(require("../dist"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('error: 4', function () {
  it('from handler, promise style', function (done) {
    (0, _nock.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error4').reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error4"),
      handler: function handler(json) {
        var a = 1;
        a.b = 2;
        return json;
      },
      responseStyle: 'unix'
    };

    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(4);
      (0, _chai.expect)(res.error).to.be.an('error');
      (0, _chai.expect)(res.httpStatus).to.equal(200);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };

    (0, _dist.default)(fetchConfig).send().catch(errorHandler).then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('from handler, callback style', function (done) {
    (0, _nock.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error4').reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error4"),
      handler: function handler(json) {
        var a = 1;
        a.b = 2;
        return json;
      }
    };

    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(4);
      (0, _chai.expect)(res.error).to.be.an('error');
      (0, _chai.expect)(res.httpStatus).to.equal(200);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };

    (0, _dist.default)(Object.assign({}, fetchConfig, {
      error: errorHandler
    })).send().then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('from success, promise style', function (done) {
    (0, _nock.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error4').reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error4")
    };

    var successHandler = function successHandler(res) {
      (0, _chai.expect)(res.status).to.equal(0);
      var a = 1;
      a.b = 2;
    };

    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(4);
      (0, _chai.expect)(res.error).to.be.an('error');
      (0, _chai.expect)(res.httpStatus).to.equal(200);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };

    (0, _dist.default)(Object.assign({}, fetchConfig, {
      success: successHandler
    })).send().catch(errorHandler).then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('from success, callback style', function (done) {
    (0, _nock.default)(_utils.ROOT).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).get('/error4').reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error4")
    };

    var successHandler = function successHandler(res) {
      (0, _chai.expect)(res.status).to.equal(0);
      var a = 1;
      a.b = 2;
    };

    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(4);
      (0, _chai.expect)(res.error).to.be.an('error');
      (0, _chai.expect)(res.httpStatus).to.equal(200);
      (0, _chai.expect)(res.headers['X-Powered-By'.toLowerCase()]).to.equal('nock');
    };

    (0, _dist.default)(Object.assign({}, fetchConfig, {
      success: successHandler,
      error: errorHandler
    })).send().then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
});