"use strict";

require("core-js/modules/es6.object.assign");

var _chai = require("chai");

var _nock = _interopRequireDefault(require("nock"));

var _dist = _interopRequireDefault(require("../dist"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('error: 5', function () {
  it('timeout, promise style', function (done) {
    (0, _nock.default)(_utils.ROOT).get('/error5').delayConnection(200).reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error5"),
      timeout: 100,
      responseStyle: 'unix'
    };

    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(5);
      (0, _chai.expect)(res.timeout).to.equal(100);
      return res;
    };

    (0, _dist.default)(fetchConfig).send().catch(errorHandler).then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('timeout, callback style', function (done) {
    (0, _nock.default)(_utils.ROOT).get('/error5').delayConnection(200).reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error5"),
      timeout: 100
    };

    var errorHandler = function errorHandler(res) {
      (0, _chai.expect)(res).to.be.an('error');
      (0, _chai.expect)(res.status).to.equal(5);
      (0, _chai.expect)(res.timeout).to.equal(100);
      return res;
    };

    (0, _dist.default)(Object.assign({}, fetchConfig, {
      error: errorHandler
    })).send().then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('no timeout, promise style', function (done) {
    (0, _nock.default)(_utils.ROOT).get('/error5').delayConnection(200).reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error5"),
      timeout: 300
    };

    var successHandler = function successHandler(res) {
      (0, _chai.expect)(res.status).to.equal(0);
    };

    (0, _dist.default)(fetchConfig).send().then(successHandler).then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('no timeout, callback style', function (done) {
    (0, _nock.default)(_utils.ROOT).get('/error5').delayConnection(200).reply(200, {
      status: 0
    });
    var fetchConfig = {
      url: "".concat(_utils.ROOT, "/error5"),
      timeout: 300
    };

    var successHandler = function successHandler(res) {
      (0, _chai.expect)(res.status).to.equal(0);
    };

    (0, _dist.default)(Object.assign({}, fetchConfig, {
      success: successHandler
    })).send().then(function () {
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
});