"use strict";

require("core-js/modules/es6.function.name");

require("core-js/modules/es6.object.assign");

var _chai = require("chai");

var _nock = _interopRequireDefault(require("nock"));

var _qs = _interopRequireDefault(require("qs"));

var _dist = _interopRequireDefault(require("../dist"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('put', function () {
  it('user3, by urlencoded', function (done) {
    (0, _nock.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /application\/x-www-form-urlencoded/
      }
    }).defaultReplyHeaders({
      'X-Powered-By': 'nock'
    }).put('/user').query({
      uid: 3
    }).reply(201, function (uri, requestBody) {
      return Object.assign(_qs.default.parse(requestBody), {
        status: 0
      });
    });
    (0, _dist.default)({
      url: "".concat(_utils.ROOT, "/user"),
      method: 'put',
      query: {
        uid: 3
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: {
        name: 'user3'
      },
      mergeHeaders: {
        poweredBy: 'X-Powered-By'
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.name).to.equal('user3');
      (0, _chai.expect)(res.status).to.equal(0);
      (0, _chai.expect)(res.poweredBy).to.equal('nock');
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
  it('user4, by JSON', function (done) {
    (0, _nock.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1',
        'Content-Type': /json/
      }
    }).put('/user').query({
      uid: 4
    }).reply(201, function (uri, requestBody) {
      return Object.assign(requestBody, {
        status: 0
      });
    });
    (0, _dist.default)({
      url: "".concat(_utils.ROOT, "/user"),
      method: 'put',
      query: {
        uid: 4
      },
      headers: {
        'X-My-Headers': '1'
      },
      dataType: 'json',
      data: {
        name: 'user4'
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.name).to.equal('user4');
      (0, _chai.expect)(res.status).to.equal(0);
      done();
    }).catch(function (err) {
      console.log(err);
    });
  });
});